# WikiEvents Dataset (English to Portuguese)

This folder contains the WikiEvents dataset translated from English into Portuguese.

## Description

WikiEvents is a document-level event extraction corpus with 3,951 event mentions covering 67 event types, extracted from 246 English Wikipedia articles.

## Translation Details

- Original language: English
- Translated to: Portuguese
- Translation approach: Automatic machine translation followed by annotation alignment using LinguAligner.

## Reference

Li, Sha, Ji, Heng, & Han, Jiawei. (2021). **Document-Level Event Argument Extraction by Conditional Generation**. *Proceedings of the 2021 Conference of the North American Chapter of the Association for Computational Linguistics: Human Language Technologies*, 894–908. Association for Computational Linguistics. [https://doi.org/10.18653/v1/2021.naacl-main.69](https://doi.org/10.18653/v1/2021.naacl-main.69)
